==> authenticated-socks-module-7.5.0-sources.jar: org/simplejavamail/internal/authenticatedsockssupport/socks5client/KeyStoreInfo.java <==
/*
 * Copyright © 2009 Benny Bottema (benny@bennybottema.com)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.simplejavamail.internal.authenticatedsockssupport.socks5client;

import org.simplejavamail.internal.util.MiscUtil;

@SuppressWarnings("SameParameterValue")
class KeyStoreInfo {

	private final String keyStorePath;
	private final String password;
	private final String type /*= "JKS"*/;

	/**
	 * Delegates to {@link #KeyStoreInfo(String, String, String)} using "JKS" as type.
	 */
	@SuppressWarnings("unused")
	public KeyStoreInfo(final String keyStorePath, final String password) {
		this(keyStorePath, password, "JKS");
	}

	public KeyStoreInfo(final String keyStorePath, final String password, final String type) {
		this.keyStorePath = MiscUtil.checkNotNull(keyStorePath, "Argument [keyStorePath] may not be null");
		this.password = MiscUtil.checkNotNull(password, "Argument [password] may not be null");
		this.type = MiscUtil.checkNotNull(type, "Argument [type] may not be null");
	}

	public String getKeyStorePath() {
		return keyStorePath;
	}

	public String getPassword() {
		return password;
	}

	public String getType() {
		return type;
	}

	@Override
	public String toString() {
		return "[KEY STORE] PATH:" + keyStorePath + " PASSWORD:xxx" + " TYPE:" + type;
	}
}

==> authenticated-socks-module-8.5.1-sources.jar: org/simplejavamail/internal/authenticatedsockssupport/socks5client/KeyStoreInfo.java <==
/*
 * Copyright © 2009 Benny Bottema (benny@bennybottema.com)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.simplejavamail.internal.authenticatedsockssupport.socks5client;

import static java.util.Objects.requireNonNull;

@SuppressWarnings("SameParameterValue")
class KeyStoreInfo {

	private final String keyStorePath;
	private final String password;
	private final String type /*= "JKS"*/;

	/**
	 * Delegates to {@link #KeyStoreInfo(String, String, String)} using "JKS" as type.
	 */
	@SuppressWarnings("unused")
	public KeyStoreInfo(final String keyStorePath, final String password) {
		this(keyStorePath, password, "JKS");
	}

	public KeyStoreInfo(final String keyStorePath, final String password, final String type) {
		this.keyStorePath = requireNonNull(keyStorePath, "Argument [keyStorePath] may not be null");
		this.password = requireNonNull(password, "Argument [password] may not be null");
		this.type = requireNonNull(type, "Argument [type] may not be null");
	}

	public String getKeyStorePath() {
		return keyStorePath;
	}

	public String getPassword() {
		return password;
	}

	public String getType() {
		return type;
	}

	@Override
	public String toString() {
		return "[KEY STORE] PATH:" + keyStorePath + " PASSWORD:xxx" + " TYPE:" + type;
	}
}
